@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: grdtrack.c 10289 2014-12-28 21:17:06Z pwessel $
+ *	$Id: grdtrack.c 10351 2016-07-06 19:28:36Z pwessel $
  *
- *	Copyright (c) 1991-2015 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2016 by P. Wessel and W. H. F. Smith
  *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -346,7 +346,10 @@ int main (int argc, char **argv)
 	ix = (gmtdefs.xy_toggle[GMT_OUT]);	iy = 1 - ix;	/* These are used for output purposes only */
 	n_expected_fields = (GMT_io.ncol[GMT_IN]) ? GMT_io.ncol[GMT_IN] : GMT_MAX_COLUMNS;
 	memset ((void *)line, 0, (size_t)BUFSIZ);
-	if (Ctrl->Z.active) GMT_io.out_col_type[0] = GMT_IS_FLOAT;	/* Since we are outputting z in the longitude column */
+	if (Ctrl->Z.active) {
+		GMT_io.out_col_type[0] = GMT_IS_FLOAT;	/* Since we are outputting z in the longitude column */
+		gmtdefs.xy_toggle[GMT_OUT] = FALSE;	/* Since no x,y involved any more */
+	}
 
 	while ((n_fields = GMT_input (fp, &n_expected_fields, &in)) >= 0 && !(GMT_io.status & GMT_IO_EOF)) {
 
