@@ -1,10 +1,10 @@
-/*	$Id: gmt_gshhg.h 10289 2014-12-28 21:17:06Z pwessel $
+/*	$Id: gmt_gshhg.h 10348 2016-04-27 19:40:24Z pwessel $
  *
  * Include file defining macros, functions and structures used in gshhg.c
  *
  * Paul Wessel, SOEST
  *
- *	Copyright (c) 1996-2015 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1996-2016 by P. Wessel and W. H. F. Smith
  *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -18,12 +18,11 @@
  *
  *	Contact info: www.soest.hawaii.edu/pwessel
  *
- *	1-JUL-2014.  For use with GSHHG version 2.3.1
+ *	1-JUL-2014.  For use with GSHHG version 2.3.1 or later
  */
 
 #ifndef _GMT_GSHHG
 #define _GMT_GSHHG
-#define _POSIX_SOURCE 1		/* GSHHG code is POSIX compliant */
 
 #include <stdio.h>
 #include <stdlib.h>
