@@ -1,15 +1,15 @@
 /*--------------------------------------------------------------------
- *	$Id: mgd77header.c 10289 2014-12-28 21:17:06Z pwessel $
+ *	$Id: mgd77header.c 10362 2016-08-20 00:20:25Z remko $
  *
- *    Copyright (c) 2004-2015 by P. Wessel and Michael Chandler
+ *    Copyright (c) 2004-2016 by P. Wessel and Michael Chandler
  *    See README file for copying and redistribution conditions.
  *--------------------------------------------------------------------*/
 /*
  * mgd77header.c reads an NGDC A77 file, determines temporal and spatial extents,
  * ten degree boxes, data columns present. Also reads header items from a file (-H<file).
- * Output: Header items determined from data and read from input are output in 
+ * Output: Header items determined from data and read from input are output in
  * H77 or raw header format (-M<r|f>).
- * 
+ *
  * Note: Program expects first row to be a header as (no header row will trigger error):
  * #rec	TZ	year	month	day	hour	min	lat		lon		ptc	twt	depth	bcc	btc	mtf1	mtf2	mag	msens	diur	msd	gobs	eot	faa	nqc	id	sln	sspn
  *
@@ -17,7 +17,7 @@
  * Date:	23-MAY-2012
  *
  */
- 
+
 #include "mgd77.h"
 #include "mgd77_codes.h"
 #include "math.h"
@@ -39,35 +39,35 @@ int main (int argc, char **argv)
 {
 	GMT_LONG i, id, rec, argno, col_listing = 3, length, id_col, t_col, x_col, y_col, saved_range, use;
 	GMT_LONG header_flag = 0, n_paths, counter[MGD77_MAX_COLS], agency_listing = 1, quad_no, n_quad;
-	
+
 	GMT_LONG error = FALSE, greenwich = FALSE, quick_summary = FALSE, dump_raw_header = FALSE;
 	GMT_LONG first = TRUE, col_summary = FALSE, read_file, dump_formatted_header = FALSE;
 	GMT_LONG quick_agencies = FALSE, dump_e77_header = FALSE, dump_hist_header = FALSE;
 	GMT_LONG quad[4] = {FALSE, FALSE, FALSE, FALSE}, b_col, m_col, f_col;
 	int tendeg[36][18], tenx, teny, nten = 0, tquad;
-	
+
 	double this_dist, this_lon, this_lat, last_lon, last_lat, dx, dy, dlon, ds, lon_w;
 	double xmin, xmax, xmin1, xmin2, xmax1, xmax2, ymin, ymax, this_time, tmin, tmax;
 	double *dvalue[MGD77_MAX_COLS];
-    
+
 	FILE *infile = NULL;
-    
+
 	time_t tt;
 	struct tm *tod = NULL;
-	
+
 	char *tvalue[MGD77_MAX_COLS], buffer[BUFSIZ], name[BUFSIZ], value[BUFSIZ], params[BUFSIZ], hinfile[BUFSIZ], line[BUFSIZ];
 	char **list = NULL;
 
 	struct MGD77_CONTROL M, Out;
 	struct MGD77_DATASET *D = NULL;
-		
+
 	time (&tt);
 	tod = localtime(&tt);
 
 	argc = (int)GMT_begin (argc, argv);		/* Initialize GMT Machinery */
-	
+
 	/* Initialize MGD77 output order and other parameters*/
-	
+
 	MGD77_Init (&M);		/* Initialize MGD77 Machinery */
 	MGD77_Init (&Out);		/* Initialize MGD77 Machinery */
 	Out.fp = GMT_stdout;
@@ -81,7 +81,7 @@ int main (int argc, char **argv)
 			case '\0':
 				error += GMT_parse_common_options (argv[i], NULL, NULL, NULL, NULL);
 				break;
-						
+
 			case 'C':	/* Get the short list [Default] */
 				switch (argv[i][2]) {
 					case 'm':
@@ -98,7 +98,7 @@ int main (int argc, char **argv)
 				}
 				col_summary = TRUE;
 				break;
-	
+
 			case 'H':
 				strcpy (hinfile, &argv[i][2]);
 				infile = fopen (hinfile, "r");
@@ -107,7 +107,7 @@ int main (int argc, char **argv)
 					exit(0);
 				}
 				break;
-                
+
 			case 'M':
 				if (argv[i][2] == 'f') {
 					dump_formatted_header = TRUE;
@@ -128,7 +128,7 @@ int main (int argc, char **argv)
 					exit (EXIT_FAILURE);
 				}
 				break;
-	
+
 			case 'I':
 				MGD77_Process_Ignore (argv[i][1], &argv[i][2]);
 				break;
@@ -164,23 +164,23 @@ int main (int argc, char **argv)
 				}
 				quick_agencies = TRUE;
 				break;
-	
+
 			default:		/* Options not recognized */
 				error = TRUE;
 				break;
 		}
 	}
-	
+
 	if (error) exit (EXIT_FAILURE);
 
 	/* Check that the options selected are mutually consistent */
-	
+
 	if (GMT_give_synopsis_and_exit || argc == 1 || header_flag == 1) {	/* Display usage */
 		fprintf (stderr, "mgd77header %s - Extract information about MGD77 files\n\n", MGD77_VERSION);
 		fprintf (stderr, "usage: mgd77header <cruise(s)> [-C[m|e]] [-E[m|e]] [-H<file> [-I<code>] [-Mf[<item>]|r|e|h] [-L[v]] [-V]\n\n");
-         
+
 		if (GMT_give_synopsis_and_exit) exit (EXIT_FAILURE);
-              
+
 		MGD77_Cruise_Explain ();
 		fprintf (stderr, "\tOPTIONS:\n\n");
 		fprintf (stderr, "\t-C List abbreviations of all columns present for each cruise\n");
@@ -209,7 +209,7 @@ int main (int argc, char **argv)
 		exit (EXIT_FAILURE);
 	}
 
-	if (!(dump_raw_header + dump_e77_header + dump_hist_header + quick_summary + col_summary + dump_formatted_header + quick_agencies ) == 1) {
+	if (dump_raw_header + dump_e77_header + dump_hist_header + quick_summary + col_summary + dump_formatted_header + quick_agencies == 0) {
 		fprintf(stderr, "%s: ERROR: Specify one of -C, -E, -L, or -M\n", GMT_program);
 		exit (EXIT_FAILURE);
 	}
@@ -226,32 +226,32 @@ int main (int argc, char **argv)
 	}
 
 	n_paths = MGD77_Path_Expand (&M, argv, argc, &list);	/* Get list of requested IDs */
-	
+
 	if (n_paths == 0) {
 		fprintf(stderr, "%s: ERROR: No cruises given\n", GMT_program);
 		exit (EXIT_FAILURE);
 	}
-	
+
 	read_file = (quick_summary || dump_raw_header || dump_formatted_header);
-	
+
 	saved_range = GMT_io.geo.range;	/* We may have to reset thisso keep a copy */
 	GMT_io.out_col_type[0] = GMT_IS_LON;	GMT_io.out_col_type[1] = GMT_IS_LAT;
-	GMT_io.out_col_type[2] = M.time_format;	
+	GMT_io.out_col_type[2] = M.time_format;
 	if (quick_summary) {
 		sprintf (buffer, "#Cruise %sID      %sWest    %sEast    %sSouth   %sNorth   %sStartTime%s%sEndTime%s%s%sDist%snRec",
 		gmtdefs.field_delimiter, gmtdefs.field_delimiter, gmtdefs.field_delimiter, gmtdefs.field_delimiter, gmtdefs.field_delimiter, gmtdefs.field_delimiter,
 		gmtdefs.field_delimiter, gmtdefs.field_delimiter, gmtdefs.field_delimiter, gmtdefs.field_delimiter, gmtdefs.field_delimiter, gmtdefs.field_delimiter);
 		GMT_fputs (buffer, GMT_stdout);
-	}	
+	}
 
 	use = (M.original || M.format != MGD77_FORMAT_CDF) ? MGD77_ORIG : MGD77_REVISED;
-	
+
 	for (argno = 0; argno < n_paths; argno++) {		/* Process each ID */
-	
+
 		if (MGD77_Open_File (list[argno], &M, MGD77_READ_MODE)) continue;
 
 		if (gmtdefs.verbose) fprintf (stderr, "%s: Now processing cruise %s\n", GMT_program, list[argno]);
-		
+
 		D = MGD77_Create_Dataset ();
 
 		if (read_file && MGD77_Read_File_nohdr (list[argno], &M, D)) {
@@ -270,7 +270,7 @@ int main (int argc, char **argv)
 		m_col = MGD77_Get_Column ("mag", &M);
 		f_col = MGD77_Get_Column ("faa", &M);
 		id_col = MGD77_Get_Column ("id", &M);
-		
+
 		GMT_make_dnan (tmin);
 		GMT_make_dnan (tmax);
 		this_dist = this_lon = this_lat = ds = this_time = 0.0;
@@ -331,7 +331,7 @@ int main (int argc, char **argv)
 			}
 			ymin = MIN (this_lat, ymin);
 			ymax = MAX (this_lat, ymax);
-            
+
             /* Determine 10x10 degree boxes crossed */
             teny = floor ((this_lat/10)+9);
             if (this_lon > 180) tenx = ceil (((this_lon-360)/10)+18);
@@ -382,7 +382,7 @@ int main (int argc, char **argv)
 		else {						/* Either will do, use default settings */
 			xmin = xmin1;
 			xmax = xmax1;
-		} 
+		}
 		/* Avoid discontinuity at Dateline */
 		if (xmin > 180) xmin -= 360.0;
 	        if (xmax > 180) xmax -= 360.0;
@@ -423,7 +423,7 @@ int main (int argc, char **argv)
                     i++;
 					if (tenx >= 18) {
 						tquad = 3;
-						if (teny >= 9) 
+						if (teny >= 9)
 							tquad = 1;
 					} else {
 						tquad = 5;
@@ -455,7 +455,7 @@ int main (int argc, char **argv)
 		strncpy (MGD77_Header_Lookup[id].ptr[MGD77_M77_SET],value,MGD77_Header_Lookup[id].length);
 		sprintf (value,"11111");
 		if (counter[b_col]) value[0] = '5';
-		if (counter[m_col]) value[1] = '5';     
+		if (counter[m_col]) value[1] = '5';
 		if (counter[f_col]) value[2] = '5';
 		strcpy(params,value);
 		sprintf (name,"Parameters_Surveyed_Code");
@@ -493,7 +493,7 @@ int main (int argc, char **argv)
 		sprintf (name,"Survey_Arrival_Day");
 		id = MGD77_Get_Header_Item (&M, name);
 		strncpy (MGD77_Header_Lookup[id].ptr[MGD77_M77_SET],&value[8],2);
-        
+
 		/* Copy header items from header input file */
 		if (infile) {
 			while (fgets (line,BUFSIZ,infile)) {
@@ -506,7 +506,7 @@ int main (int argc, char **argv)
 				strncpy (MGD77_Header_Lookup[id].ptr[MGD77_M77_SET],value,MGD77_Header_Lookup[id].length);
 			}
 		}
-        
+
 		if (first && quick_summary) {	/* Output all column headers */
 			for (i = 0; i < M.n_out_columns; i++) {
 				if (i == id_col || i == t_col || i == x_col || i == y_col) continue;
@@ -515,7 +515,7 @@ int main (int argc, char **argv)
 			}
 			GMT_fputs ("\n", GMT_stdout);
 		}
-		
+
 		if (col_summary) {	/* Just list names and info for any extra columns */
 			for (i = 0, first = TRUE; i < M.n_out_columns; i++) {
 				if (i == id_col || i == t_col || i == x_col || i == y_col) continue;
@@ -533,11 +533,11 @@ int main (int argc, char **argv)
 		}
 
 		if (dump_formatted_header) {	/* Dump of header items, one per line */
-			MGD77_Dump_Header_Params (&M, D->H.mgd77[use]);	
+			MGD77_Dump_Header_Params (&M, D->H.mgd77[use]);
 			MGD77_Close_File (&M);
 			continue;
 		}
-        
+
 		if (dump_raw_header) {	/* Write entire MGD77 header */
 			if (infile == NULL) {
 				GMT_fputs ("-------------------------------", GMT_stdout);
@@ -573,7 +573,7 @@ int main (int argc, char **argv)
 			GMT_ascii_output_one (GMT_stdout, ymin, 1);	GMT_fputs (gmtdefs.field_delimiter, GMT_stdout);
 			GMT_ascii_output_one (GMT_stdout, ymax, 1);	GMT_fputs (gmtdefs.field_delimiter, GMT_stdout);
 			GMT_ascii_output_one (GMT_stdout, tmin, 2);	GMT_fputs (gmtdefs.field_delimiter, GMT_stdout);
-			GMT_ascii_output_one (GMT_stdout, tmax, 2);	GMT_fputs (gmtdefs.field_delimiter, GMT_stdout);						
+			GMT_ascii_output_one (GMT_stdout, tmax, 2);	GMT_fputs (gmtdefs.field_delimiter, GMT_stdout);
 			sprintf (buffer, "%ld%s%ld", (GMT_LONG)irint (this_dist), gmtdefs.field_delimiter, D->H.n_records);
 			GMT_fputs (buffer, GMT_stdout);
 			for (i = 1; i < M.n_out_columns; i++) {
@@ -606,7 +606,7 @@ int main (int argc, char **argv)
 
 		MGD77_Free (D);
 	}
-		
+
 	MGD77_Path_Free ((int)n_paths, list);
 	MGD77_end (&M);
 
@@ -616,7 +616,7 @@ int main (int argc, char **argv)
 int MGD77_Read_File_nohdr (char *file, struct MGD77_CONTROL *F, struct MGD77_DATASET *S)
 {
 	int err = 0;
-    
+
 	switch (F->format) {
 		case MGD77_FORMAT_M77:	/* Plain MGD77 file */
 		case MGD77_FORMAT_M7T:	/* Plain MGD77T file */
@@ -630,7 +630,7 @@ int MGD77_Read_File_nohdr (char *file, struct MGD77_CONTROL *F, struct MGD77_DAT
 			fprintf (stderr, "%s: Bad format (%d)!\n", GMT_program, F->format);
 			err = MGD77_UNKNOWN_FORMAT;
 	}
-    
+
 	return (err);
 }
 
@@ -638,44 +638,44 @@ int MGD77_Read_File_nohdr (char *file, struct MGD77_CONTROL *F, struct MGD77_DAT
 int MGD77_Read_File_asc_nohdr (char *file, struct MGD77_CONTROL *F, struct MGD77_DATASET *S)	  /* Will read all MGD77 records in current file */
 {
 	int err;
-    
+
 	err = MGD77_Open_File (file, F, MGD77_READ_MODE);
 	if (err) return (err);
-    
+
 	MGD77_Select_All_Columns (F, &S->H);	/* We know we only deal with items from set 0 here */
 
 	err = MGD77_Read_Header_Record_nohdr (file, F, &S->H);  /* Will read the entire 24-section header structure */
 	if (err) return (err);
-    
+
 	err = MGD77_Read_Data_asc (file, F, S);	  /* Will read all MGD77 records in current file */
 	if (err) return (err);
-    
+
 	MGD77_Close_File (F);
-    
+
 	return (MGD77_NO_ERROR);
 }
 
 int MGD77_Read_File_cdf_nohdr (char *file, struct MGD77_CONTROL *F, struct MGD77_DATASET *S)
 {
 	int err;
-    
+
 	MGD77_Select_All_Columns (F, &S->H);
 
 	err = MGD77_Read_Header_Record_nohdr (file, F, &S->H);  /* Will read the entire 24-section header structure */
 	if (err) return (err);
-    
+
 	err = MGD77_Read_Data_cdf (file, F, S);
 	if (err) return (err);
-    
+
 	MGD77_nc_status (nc_close (F->nc_id));
-    
+
 	return (MGD77_NO_ERROR);
 }
 
 int MGD77_Read_Header_Record_nohdr (char *file, struct MGD77_CONTROL *F, struct MGD77_HEADER *H)
 {	/* Reads the header structure form a MGD77[+] file */
 	int error;
-    
+
 	switch (F->format) {
 		case MGD77_FORMAT_M77:	/* Will read MGD77 headers from MGD77 files or ascii tables */
 			error = MGD77_Read_Header_Record_m77_nohdr (file, F, H);
@@ -693,9 +693,9 @@ int MGD77_Read_Header_Record_nohdr (char *file, struct MGD77_CONTROL *F, struct
 			error = MGD77_UNKNOWN_FORMAT;
 			break;
 	}
-    
+
 	MGD77_Init_Ptr (MGD77_Header_Lookup, H->mgd77);	/* set pointers */
-    
+
 	return (error);
 }
 
@@ -704,11 +704,11 @@ int MGD77_Read_Header_Record_m77_nohdr (char *file, struct MGD77_CONTROL *F, str
 	char *MGD77_header[MGD77_N_HEADER_RECORDS], line[BUFSIZ], *not_used = NULL;
 	int i, sequence, err, n_eols, c, n;
 	struct GMT_STAT buf;
-    
+
 	n_eols = c = n = 0;	/* Also shuts up the boring compiler warnings */
-    
+
 	/* argument file is generally ignored since file is already open */
-    
+
 	memset ((void *)H, '\0', sizeof (struct MGD77_HEADER));	/* Completely wipe existing header */
 	if (F->format == MGD77_FORMAT_M77) {			/* Can compute # records from file size because format is fixed */
 		if (GMT_STAT (F->path, &buf)) {	/* Inquiry about file failed somehow */
@@ -725,7 +725,7 @@ int MGD77_Read_Header_Record_m77_nohdr (char *file, struct MGD77_CONTROL *F, str
 		H->n_records = n;					/* 0 is the header size */
 		rewind (F->fp);					/* Go back to beginning of file */
 #else
-        
+
 		/* Test if we need to use +2 because of \r\n. We could use the above solution but this one looks more (time) efficient. */
 		not_used = fgets (line, BUFSIZ, F->fp);
 		rewind (F->fp);					/* Go back to beginning of file */
@@ -738,25 +738,25 @@ int MGD77_Read_Header_Record_m77_nohdr (char *file, struct MGD77_CONTROL *F, str
 		while (fgets (line, BUFSIZ, F->fp)) if (line[0] != '#') H->n_records++;	/* Count every line except comments  */
 		rewind (F->fp);					/* Go back to beginning of file */
 	}
-    
+
 	/* Read Sequences No 01-24: */
-    
+
 	for (sequence = 0; sequence < MGD77_N_HEADER_RECORDS; sequence++) {
 		MGD77_header[sequence] = (char *)GMT_memory (VNULL, (size_t)(MGD77_HEADER_LENGTH + 2), sizeof (char), GMT_program);
 /*		if ((err = MGD77_Read_Header_Sequence (F->fp, MGD77_header[sequence], sequence+1))) return (err);*/
 	}
 	if (F->format != MGD77_FORMAT_M77) not_used = fgets (line, BUFSIZ, F->fp);	/* Skip the column header for tables */
-    
+
 	for (i = 0; i < 2; i++) H->mgd77[i] = (struct MGD77_HEADER_PARAMS *) GMT_memory (VNULL, (size_t)1, sizeof (struct MGD77_HEADER_PARAMS), GMT_program);	/* Allocate parameter header */
-    
+
 /*	if ((err = MGD77_Decode_Header_m77 (H->mgd77[MGD77_ORIG], MGD77_header, MGD77_FROM_HEADER))) return (err);	 Decode individual items in the text headers */
 	for (sequence = 0; sequence < MGD77_N_HEADER_RECORDS; sequence++) GMT_free ((void *)MGD77_header[sequence]);
-    
+
 	/* Fill in info in F */
-    
+
 	MGD77_set_plain_mgd77 (H, FALSE);				/* Set the info for the standard 27 data fields in MGD-77 files */
 	if ((err = MGD77_Order_Columns (F, H))) return (err);	/* Make sure requested columns are OK; if not given set defaults */
-    
+
 	return (MGD77_NO_ERROR);	/* Success, it seems */
 }
 
@@ -764,30 +764,30 @@ int MGD77_Read_Header_Record_m77t_nohdr (char *file, struct MGD77_CONTROL *F, st
 {	/* Applies to MGD77T files */
 	char *MGD77_header, line[BUFSIZ], *not_used = NULL;
 	int i, err, n_eols, c, n;
-    
+
 	n_eols = c = n = 0;	/* Also shuts up the boring compiler warnings */
-    
+
 	/* argument file is generally ignored since file is already open */
-    
+
 	memset ((void *)H, '\0', sizeof (struct MGD77_HEADER));	/* Completely wipe existing header */
 	/* Since we do not know the number of records, we must quickly count lines */
 	while (fgets (line, BUFSIZ, F->fp)) H->n_records++;	/* Count every line */
 	rewind (F->fp);					/* Go back to beginning of file */
-    
+
 	not_used = fgets (line, BUFSIZ, F->fp);		/* Skip the column header  */
-    
+
 	MGD77_header = (char *)GMT_memory (VNULL, (size_t)MGD77T_HEADER_LENGTH, sizeof (char), GMT_program);
 	// not_used = fgets (MGD77_header, BUFSIZ, F->fp);			/* Read the entire header record  */
-    
+
 	for (i = 0; i < 2; i++) H->mgd77[i] = (struct MGD77_HEADER_PARAMS *) GMT_memory (VNULL, (size_t)1, sizeof (struct MGD77_HEADER_PARAMS), GMT_program);	/* Allocate parameter header */
-    
+
 	if ((err = MGD77_Decode_Header_m77t (H->mgd77[MGD77_ORIG], MGD77_header))) return (err);	/* Decode individual items in the text headers */
 	GMT_free ((void *)MGD77_header);
-    
+
 	/* Fill in info in F */
-    
+
 	MGD77_set_plain_mgd77 (H, TRUE);			/* Set the info for the standard 27 data fields in MGD-77 files */
 	if ((err = MGD77_Order_Columns (F, H))) return (err);	/* Make sure requested columns are OK; if not given set defaults */
-    
+
 	return (MGD77_NO_ERROR);	/* Success, it seems */
 }
