@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: mgd77info.c 10289 2014-12-28 21:17:06Z pwessel $
+ *	$Id: mgd77info.c 10366 2016-10-01 23:38:10Z pwessel $
  *
- *    Copyright (c) 2004-2015 by P. Wessel
+ *    Copyright (c) 2004-2016 by P. Wessel
  *    See README file for copying and redistribution conditions.
  *--------------------------------------------------------------------*/
 /*
@@ -177,7 +177,7 @@ int main (int argc, char **argv)
 		exit (EXIT_FAILURE);
 	}
 
-	if (!(dump_raw_header + dump_e77_header + dump_hist_header + quick_summary + col_summary + dump_formatted_header + quick_agencies ) == 1) {
+	if ((!(dump_raw_header + dump_e77_header + dump_hist_header + quick_summary + col_summary + dump_formatted_header + quick_agencies )) == 1) {
 		fprintf(stderr, "%s: ERROR: Specify one of -C, -E, -L, or -M\n", GMT_program);
 		exit (EXIT_FAILURE);
 	}
