@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *    $Id: gmtdigitize.c 10289 2014-12-28 21:17:06Z pwessel $
+ *    $Id: gmtdigitize.c 10344 2016-03-07 01:35:42Z pwessel $
  *
- *	Copyright (c) 1991-2015 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2016 by P. Wessel and W. H. F. Smith
  *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -36,8 +36,14 @@
  *				read via fgets etc, otherwise via read.
  *
  */
- 
+
+/* Circumvent Solaris problem. See bug #817 */
+#ifdef __FreeBSD__
 #define _XOPEN_SOURCE
+#else
+#define _XOPEN_SOURCE 600
+#endif
+ 
 #ifdef HAVE_UNISTD_H
 #include <unistd.h>
 #endif
