@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: pscontour.c 10289 2014-12-28 21:17:06Z pwessel $
+ *	$Id: pscontour.c 10344 2016-03-07 01:35:42Z pwessel $
  *
- *	Copyright (c) 1991-2015 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2016 by P. Wessel and W. H. F. Smith
  *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -553,7 +553,9 @@ int main(int argc, char **argv)
 	}
 	Ctrl->contour.line_pen = Ctrl->W.pen;
 
-	for (i = ij = 0; i < np; i++, ij += 3) {	/* For all triangles */
+	if (n_contours == 0 && gmtdefs.verbose) fprintf (stderr, "%s: No contours found\n", GMT_program);
+	
+	for (i = ij = 0; n_contours && i < np; i++, ij += 3) {	/* For all triangles */
 
 		if (ind[ij] < 0) continue;	/* Skip triangles that are fully outside */
 		k = ij;
