@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: sph.c 10289 2014-12-28 21:17:06Z pwessel $
+ *	$Id: sph.c 10358 2016-08-19 20:22:25Z pwessel $
  *
- *	Copyright (c) 2008-2015 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 2008-2016 by P. Wessel and W. H. F. Smith
  *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -274,7 +274,7 @@ void ssrfpack_grid (double *x, double *y, double *z, double *w, GMT_LONG n, int
 		ist = 1;
 		for (j = 0; j < h->ny; j++) {
 			for (i = 0; i < h->nx; i++) {
-				ij = i * h->ny + (h->ny - j -1); /* Use Fortran indexing since calling program will transpose to GMT order */
+				ij = i * h->ny + j; /* Use Fortran indexing since calling program will transpose to GMT order */
 				intrc0_ (&n4, &plat[j], &plon[i], x, y, z, w, P.I.list, P.I.lptr, P.I.lend, &ist, &f[ij], &ierror);
 				if (ierror > 0) nxp++;
 	            		if (ierror < 0) {
