@@ -1,7 +1,7 @@
 /*--------------------------------------------------------------------
- *	$Id: surface.c 10289 2014-12-28 21:17:06Z pwessel $
+ *	$Id: surface.c 10345 2016-04-12 17:41:18Z pwessel $
  *
- *	Copyright (c) 1991-2015 by P. Wessel and W. H. F. Smith
+ *	Copyright (c) 1991-2016 by P. Wessel and W. H. F. Smith
  *	See LICENSE.TXT file for copying and redistribution conditions.
  *
  *	This program is free software; you can redistribute it and/or modify
@@ -44,9 +44,9 @@
  *	W. H. F. Smith
  *
  * Version 4.0 -- 5 Dec 1988:	The scratch file has been eliminated,
- *	resulting in a C->small gain in speed.   It is replaced by the 
+ *	resulting in a small gain in speed.   It is replaced by the 
  *	in core struct SURFACE_BRIGGS.  Division by xinc or grid_xinc has been
- *	replaced with multiplies by reciprocals, which also made a C->small
+ *	replaced with multiplies by reciprocals, which also made a small
  *	improvement in speed.  The computation of i, j to index a point
  *	was changed from rint(x) to floor(x + 0.5) to make it follow the
  *	convention of blockmean.  This is actually significant at times.
@@ -198,7 +198,6 @@ struct SURFACE_INFO {	/* Control structure for surface setup and execution */
 	double z_scale;			/* Root mean square range of z after removing planar trend  */
 	double r_z_scale;		/* reciprocal of z_scale  */
 	double plane_c0, plane_c1, plane_c2;	/* Coefficients of best fitting plane to data  */
-	double small;			/* Let data point coincide with node if distance < C->small */
 	double coeff[2][12];		/* Coefficients for 12 nearby points, constrained and unconstrained  */
 	double relax_old, relax_new;	/* Coefficients for relaxation factor to speed up convergence */
 	struct SURFACE_DATA  *data;
@@ -852,7 +851,6 @@ void find_nearest_point (struct SURFACE_INFO *C) {
 	iu = C->iu;
 
 	last_index = -1;
-	C->small = 0.05 * ((C->grid_xinc < C->grid_yinc) ? C->grid_xinc : C->grid_yinc);
 
 	for (i = 0; i < C->nx; i += C->grid)	/* Reset grid info */
 		for (j = 0; j < C->ny; j += C->grid)
@@ -869,11 +867,11 @@ void find_nearest_point (struct SURFACE_INFO *C) {
 	 		y0 = C->h.y_min + block_j*C->grid_yinc;
 	 		dx = (C->data[k].x - x0)*C->r_grid_xinc;
 	 		dy = (C->data[k].y - y0)*C->r_grid_yinc;
-	 		if (fabs(dx) < C->small && fabs(dy) < C->small) {	/* Close enough to assign value to node */
+	 		if (fabs(dx) < 0.05 && fabs(dy) < 0.05) {	/* Close enough to assign value to node */
 	 			iu[iu_index] = 5;
 	 			/* v3.3.4: NEW CODE
 	 			 * Since point is basically moved from (dx, dy) to (0,0) we must adjust for
-	 			 * the C->small change in the planar trend between the two locations, and then
+	 			 * the small change in the planar trend between the two locations, and then
 	 			 * possibly clip the range if constraining surfaces were given.  Note that
 	 			 * dx, dy is in -1/1 range normalized by (grid * x|y_inc) so to recover the
 	 			 * dx,dy in final grid fractions we must scale by grid */
@@ -1789,7 +1787,7 @@ double guess_surface_time (GMT_LONG factors[], GMT_LONG nx, GMT_LONG ny)
 	 * 	composite number, we will have L equal to the division
 	 * 	step made at each new grid cycle, and nxg,nyg will
 	 * 	also be smaller than nx,ny.  Thus we can hope to find
-	 *	some nx,ny for which the total value of T is C->small.
+	 *	some nx,ny for which the total value of T is small.
 	 *
 	 * The above is pure speculation and has not been derived
 	 * empirically.  In actual practice, the distribution of the
